/* TI-83 Definitons File */

#ifndef __TILOADED__
#define __TILOADED__ 1

/* Macros

Macro Name      Description
----------------------------------------------------------------------------
clrscrn         Clears The Text form the Screen
clrlcd          Clears the hole LCD screen
indicatoroff    This turns the annoying run indicator off
indicatoron     This turns the annoying run indicator on
displaygraph    This funtion display whatever grafing equations are stored
                in the calculator.
nl              This funtion makes a new line on the screen like a \n in
		Most C programing

screencopy	This command copies the ti backbuffer to the screen
clearbuffer	This command clears the tibackbuffer

*/

#define clrscrn         asm("\tcall\t_clrScrnFULL\n")
#define clrlcd          asm("\tcall\t_CLRLCDFULL\n")

#define indicatoroff    asm("\tcall\t_runIndicOff\n")
#define indicatoron     asm("\tcall\t_runIndicOn\n")

#define displaygraph    asm("\tcall\t_PDspGrph\n");

#define nl              asm("\tcall\t_newline\n");

#define screencopy      asm("\tcall\t_GRBUFCPY_V\n");

#define clearbuffer     asm("\tcall\t_GRBUFCLR\n");

/* Pixel Defiations

These are used when calling fuctions like line, pixel, and Box

PT_OFF          Turns the pixel/pixels off
PT_ON           Turns the pixel/pixels on
PT_CHG          Inverts the pixel/pixels

*/

#define PT_OFF          0x00
#define PT_ON           0x01
#define PT_CHG          0x02

/* Basic TI Commands

        Function        Description
--------------------------------------------------------------------------
        setxy(x,y)      This funtion moves the text cursor to the speifed
                        (x,y) location

        putm(c)         Puts a charter on the current location

        putc(c)         Puts the charter on the current location and move the
                        cursor over one space

        puts(str)       This command puts a spefied string at the current
                        cursor location and moves the cursor location up

        getkey()        This command waits for a key or the APD register
                        to clear. The calculator will be in low power stand-
                        by during this process. It returns a value refer
                        to the k* table.
*/

setxy(x,y) char x, y; {
#asm
        ld      hl,2
        add     hl,sp
        ld      a,(hl)
        ld      (CURROW),a
        inc     hl
        inc     hl
        ld      a,(hl)
        ld      (CURCOL),a
#endasm
}

putm(c) char c; {
#asm
        ld      hl,2
        add     hl,sp
        ld      a,(hl)
        call    _putmap
#endasm
}

putc(c) char c; {
#asm
        ld      hl,2
        add     hl,sp
        ld      a,(hl)
        call    _putc
#endasm
}

puts(str)
char* str;
{
#asm
        ld      hl,2
        add     hl,sp
        ld      a,(hl)
        inc     hl
        ld      h,(hl)
        ld      l,a
        call    _puts
#endasm
}

getkey()
{
#asm
        call    _getkey
        ld      l,a
        xor     a
        ld      h,a
#endasm
}

/* These are the values that would be returned by getkey() */
/* Need to be sorted! */

#define kRight		0x01
#define kLeft		0x02
#define kUp		0x03
#define kDown		0x04
#define kEnter     	0x05
#define kClear     	0x09
#define kDEL       	0x0a
#define kBOL       	0x0e
#define kEOL       	0x0f
#define kPrgm      	0x20
#define kZOOM      	0x2E
#define kStat      	0x31
#define kMATH      	0x32
#define kVARS      	0x35
#define kMATRIX    	0x37
#define kGRAPH    	0x44
#define kMODE      	0x45
#define kWINDOW    	0x48
#define kYEQU      	0x49
#define kTRACE     	0x5A
#define kAdd       	0x80
#define kSub       	0x81
#define kMul       	0x82
#define kDiv       	0x83
#define kExpon     	0x84
#define kLParen    	0x85
#define kRParen    	0x86
#define kStore     	0x8A
#define kCOMMA     	0x8B
#define kChs       	0x8C
#define kDecPnt    	0x8D
#define k0         	0x8E
#define k1         	0x8F
#define k2         	0x90
#define k3         	0x91
#define k4         	0x92
#define k5         	0x93
#define k6         	0x94
#define k7         	0x95
#define k8         	0x96
#define k9         	0x97
#define kVarx      	0xB4
#define kINV       	0xB6
#define kSin       	0xB7
#define kCos       	0xB9
#define kTan       	0xBB
#define kSQUARE    	0xBD
#define kLN        	0xBF
#define kLOG       	0xC1

#define KCLEAR     0x09
#define kINS       0x0B
#define kRecall    0x0C
#define kLastEnt   0x0D
#define kDRAW      0x2F
#define kSPLOT     0x30
#define kTEST      0x33
#define kMem       0x36
#define kDIST      0x38
#define kANGLE     0x39
#define kLIST      0x3A
#define kCALC      0x3B
#define kFIN       0x3C
#define kCATALOG   0x3E
#define kQuit      0x40
#define kLinkIO    0x41
#define kTABLE     0x4A
#define kTBLSET    0x4B
#define kFORMAT    0x57
#define kLBRACK    0x87
#define kRBRACK    0x88
#define kEE        0x98
#define kPi        0xB5
#define kASin      0xB8
#define kACos      0xBA
#define kATan      0xBC
#define kSQRT      0xBE
#define kEXP       0xC0
#define kALOG      0xC2
#define kANS       0xC5
#define kLBRACE    0xEC
#define KCONSTeA   0xEF
#define kL3A       0xF5
#define kL6A       0xF8
#define kWNA       0xFB
#define kRBracE    0xED
#define ki         0xEE
#define kL1A       0xF3
#define kL2A       0xF4
#define kL4A       0xF6
#define kL5A       0xF7
#define kUNA       0xF9
#define kVNA       0xFA
#define kDown      0x04
#define KCLEAR     0x09
#define kLBRACE    0xEC
#define kEXP       0xC0
#define kACos      0xBA
#define kALOG      0xC2
#define ANS        0xC5
#define kDRAW      0x2F
#define kSQRT      0xBE
#define kUp        0x03
#define kL3A       0xF5
#define kLIST      0x3A
#define kFIN       0x3C
#define kL6A       0xF8
#define CATALOG    0x3E
#define kTEST      0x33
#define kWNA       0xFB
#define kL1A       0xF3
#define kRBracE    0xED
#define kL4A       0xF6
#define kTABLE     0x4A
#define kATan      0xBC
#define kUNA       0xF9
#define kCALC      0x3B
#define kLastEnt   0x0D
#define kDIST      0x38
#define kEE        0x98
#define kFORMAT    0x57
#define kMem       0x36
#define kASin      0xB8
#define kTBLSET    0x4B
#define kRBRACK    0x88
#define ki         0xEE
#define kANGLE     0x39
#define kSPLOT     0x30
#define kLBRACK    0x87
#define kL2A       0xF4
#define kLinkIO    0x41
#define KCONSTeA   0xEF
#define kL5A       0xF7
#define kQuit      0x40
#define kPi        0xB5
#define kVNA       0xFA
#define kRecall    0x0C
#define kINS       0x0B
#define kALPHADOWN   0x08
#define kClear       0x09
#define kCapL        0xA5
#define kCapV        0xAF
#define kLeft        0x02
#define kCapM        0xA6
#define kCapW        0xB0
#define kRight       0x01
#define kQUEST       0xCA
#define kcapN        0xA7
#define kCapX        0xB1
#define kALPHAUP     0x07
#define kTHETA       0xCC
#define kSTAT        0x31
#define kCapY        0xB2
#define kCapE        0x9E
#define kSPACE       0x99
#define kCapZ        0xB3
#define kCapF        0x9F
#define kCapO        0xA8
#define kCapG        0xA0
#define kCapP        0xA9
#define kGRAPH       0x44
#define kCapH        0xA1
#define kCapQ        0xAA
#define kTRACE       0x5A
#define kALPHAENTER  0x06
#define kVARS        0x35
#define kCapR        0xAB
#define kZOOM        0x2E
#define kQUOTE       0xCB
#define kCapS        0xAC
#define kWINDOW      0x48
#define kCapA        0x9A
#define kcolon       0xC6
#define kCapT        0xAD
#define kYEQU        0x49
#define kCapB        0x9B
#define kCapI        0xA2
#define kVarx        0xB4
#define kCapC        0x9C
#define kCapJ        0xA3
#define kMODE        0x45
#define kCapD        0x9D
#define kCapK        0xA4
#define kCapU        0xAE

#endif
